@@ -27,10 +27,10 @@ class cisco_None:
         #LOG Checking
         try:
             cursor.execute('''INSERT INTO logtable(devicename, model, script)
-                    VALUES(?,?,?)''', (devicename, model,self.__class__.__name__,))
+                    VALUES(?,?,?)''', (devicename+'(template not found)', model+'(template not found)',self.__class__.__name__+'(template not found)',))
         except:
             cursor.execute('''INSERT INTO logtable(devicename, model, script)
-                    VALUES(?,?,?)''', (self.file+'-'+'error', self.file+'-'+'error',self.file+'-'+'error',))
+                    VALUES(?,?,?)''', (self.file+'-'+'error'+'(template not found)', self.file+'-'+'error'+'(template not found)',self.file+'-'+'error'+'(template not found)',))
         db.commit()             
         db.close()
 
