@@ -546,7 +546,7 @@ class new_file_identification:
                     print('Executing None')
                     cisco_None(file)
                     
-            except NameError:
-                raise
+            #except NameError:
+                #raise
             except:
                 pass
